.. Copyright (C) 2014-2020 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.postfix`` Ansible role can be used to install and manage
`Postfix`__, a SMTP server. It allows configuration of Postfix using Ansible
inventory variables, and provides a flexible API to the Postfix configuration
for other Ansible roles when it's used as a role dependency.

.. __: https://en.wikipedia.org/wiki/Postfix_%28software%29
